stereo.tools.FindMarker
=======================

.. currentmodule:: stereo.tools

.. autoclass:: FindMarker

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FindMarker.__init__
      ~FindMarker.add_result
      ~FindMarker.check_param
      ~FindMarker.fit
      ~FindMarker.get_params
      ~FindMarker.merge_groups_data
      ~FindMarker.sparse2array
   
   

   
   
   